@@ -1,8 +1,8 @@
 from unittest import TestCase
 
 from pythautomata.automata_definitions.weighted_tomitas_grammars import WeightedTomitasGrammars
-from pythautomata.model_exporters.wfa_image_exporter import WFAImageExporter
-from pythautomata.model_exporters.wfa_image_exporter_with_partition_mapper import WFAImageExporterWithPartitionMapper
+from pythautomata.model_exporters.image_exporters.wfa_pdf_image_exporter import WFAImageExporter
+from pythautomata.model_exporters.image_exporters.wfa_pdf_image_exporter_with_partition_mapper import WFAImageExporterWithPartitionMapper
 from pythautomata.utilities.probability_partitioner import TopKProbabilityPartitioner
 from pythautomata.model_exporters.partition_mapper import TopKPartitionMapper
 
